# arxivAssistant
A small package to access the daily astronomy articles from arXiv.org through the console. It relies on [textual](https://github.com/Textualize/textual) for an interactive exploration in an OS agnostic framework. This is very early work and I hope to add functionalities over the time!  

<p align="center">
<img src="https://github.com/renecotyfanboy/arxivAssistant/blob/master/docs/images/app_demo.png" width="700"/>
</p>

It can be installed with pip using the following command

```pip install arxivAssistant --upgrade```

Once installed, you can use it from the command line:

```arxiv-today```
